@@ -8,7 +8,6 @@ use App::MechaCPAN qw/:go/;
 
 our @args = (
   'threads!',
-  'jobs=i',
   'skip-tests!',
   'skip-local!',
   'skip-lib!',
@@ -87,7 +86,7 @@ sub go
     q[-Accflags=-DAPPLLIB_EXP=\"] . join( ":", @otherlib ) . q[\"],
     qq[-A'eval:scriptdir=$dest_dir/bin'],
   );
-  my @make = ( "make", "-j" . ( $opts->{jobs} // 2 ) );
+  my @make = ( $Config{make} );
 
   if ( $opts->{threads} )
   {
@@ -286,10 +285,6 @@ C<$version> is either 0 or 1 parameter:
 
 By default, perl is compiled without threads. If you'd like to enable threads, use this argument.
 
-=head3 jobs
-
-How many make jobs to use when running make. Defaults to 2.
-
 =head3 skip-tests
 
 Test for perl are ran by default. If you are sure that the tests will pass and you want to save some time, you can skip the testing phase with this option.
@@ -302,6 +297,10 @@ Since perl and modules will be installed by L<App::MechaCPAN> into C<local/>, by
 
 If a C<lib/> directory exists in the same directory as the C<local/> directory, then C<lib/> will also bee added to C<@INC>. This is helpful if you're installing to run an application that includes a C<lib/> directory. If you do not want this to be added, use this flag.
 
+=head1 WIN32 LIMITATION
+
+Building perl from scratch on Win32 is nothing like building it on other platforms. At this point, the perl command does not work on Win32.
+
 =head1 AUTHOR
 
 Jon Gentle E<lt>cpan@atrodo.orgE<gt>
